#!/usr/bin/python
# -*- coding: UTF-8 -*-

import requests
import sys

if sys.version > '3':
    import urllib.request as urllib2  
else: 
    import urllib2


def wx_get_req(url, params):
    return requests.get(url, params)

def wx_post_req(url, params, img=None, bodyStr=None):
    ret = file_get_contents(img) if img else bodyStr
    return requests.post(url, params=params, data=ret)

#img to str
def file_get_contents(filename, use_include_path = 0, context = None, offset = -1, maxlen = -1):
    if (filename.find('://') > 0):
        ret = urllib2.urlopen(filename).read()
        if (offset > 0):
            ret = ret[offset:]
        if (maxlen > 0):
            ret = ret[:maxlen]
        return ret
    else:
        fp = open(filename,'rb')
        try:
            if (offset > 0):
                fp.seek(offset)
            ret = fp.read(maxlen)
            return ret
        finally:
            fp.close( )



#!/usr/bin/env python
# -*-coding: utf-8 -*-

try :
    from setuptools import setup
except :
    from distutils.core import setup
setup(
    name='wx-sdk',
    version='1.0.1',
    description='wangxiang Python SDK',
    long_description=open('README.txt').read(),
    author='wanxiang',
    author_email='wanxiang@jd.com',
    maintainer='wanxiang',
    maintainer_email='wanxiang@jd.com',
    license='BSD License',
    packages=['wx-sdk'],
    url='https://wx.jcloud.com/',
    classifiers=[
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: Implementation',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)
